@@ -379,10 +379,12 @@ CmdTech(w, cmd)
 	    break;
 
 	case TECH_REVERT:
+	    {
+	    TileTypeBitMask lockmask, *rMask;
+	    TileType ctype;
+
 	    if (cmd->tx_argc == 3)
 	    {
-		TileTypeBitMask lockmask, *rMask;
-		TileType ctype;
 
 		TTMaskZero(&lockmask);
 		if (!strcmp(cmd->tx_argv[2], "*"))
@@ -393,6 +395,7 @@ CmdTech(w, cmd)
 		TTMaskClearMask(&DBActiveLayerBits, &lockmask);
 		TTMaskAndMask(&lockmask, &DBTechActiveLayerBits);
 		TTMaskSetMask(&DBActiveLayerBits, &lockmask);
+
 	    }
 	    else if (cmd->tx_argc == 2)
 	    {
@@ -402,6 +405,35 @@ CmdTech(w, cmd)
 	    }
 	    else
 		goto wrongNumArgs;
+
+	    // Handle contact types, which involve a bit more than
+	    // just setting the active layer mask, as paint/erase
+	    // tables need to be manipulated
+
+	    for (ctype = TT_TECHDEPBASE; ctype < DBNumUserLayers; ctype++)
+		if (DBIsContact(ctype))
+		    if (TTMaskHasType(&DBActiveLayerBits, ctype))
+			DBUnlockContact(ctype);
+		    else
+			DBLockContact(ctype);
+
+	    for (ctype = DBNumUserLayers; ctype < DBNumTypes; ctype++)
+	    {
+		TileTypeBitMask testmask;
+		rMask = DBResidueMask(ctype);
+		TTMaskAndMask3(&testmask, &DBActiveLayerBits, rMask);
+		if (TTMaskEqual(&testmask, rMask))
+		{
+		    TTMaskSetType(&DBActiveLayerBits, ctype);
+		    DBUnlockContact(ctype);
+		}
+		else if (TTMaskIntersect(&DBActiveLayerBits, rMask))
+		{
+		    TTMaskClearType(&DBActiveLayerBits, ctype);
+		    DBLockContact(ctype);
+		}
+	    }
+	    }
 	    break;
 
 	case TECH_DRC:
@@ -1189,12 +1221,15 @@ cmdWhatCellFunc(selUse, realUse, transform, foundAny)
 				 * use found.
 				 */
 {
+    /* Forward reference */
+    char *dbGetUseName();
+
     if (!*foundAny)
     {
 	TxPrintf("Selected subcell(s):\n");
 	*foundAny = TRUE;
     }
-    TxPrintf("    Instance \"%s\" of cell \"%s\"\n", realUse->cu_id,
+    TxPrintf("    Instance \"%s\" of cell \"%s\"\n", dbGetUseName(realUse),
 	    realUse->cu_def->cd_name);
     return 0;
 }
@@ -1211,10 +1246,12 @@ cmdWhatCellListFunc(selUse, realUse, transform, newobj)
     Tcl_Obj *newobj;		/* Tcl list object holding use names */
 {
     Tcl_Obj *tuple;
+    /* Forward reference */
+    char *dbGetUseName();
 
     tuple = Tcl_NewListObj(0, NULL);
     Tcl_ListObjAppendElement(magicinterp, tuple,
-		Tcl_NewStringObj(realUse->cu_id, -1));
+		Tcl_NewStringObj(dbGetUseName(realUse), -1));
     Tcl_ListObjAppendElement(magicinterp, tuple,
 		Tcl_NewStringObj(realUse->cu_def->cd_name, -1));
     Tcl_ListObjAppendElement(magicinterp, newobj, tuple);
