@@ -1397,8 +1397,13 @@ dbReadProperties(cellDef, line, len, f, scalen, scaled)
     int scalen;		/* Scale up by this factor */
     int scaled;		/* Scale down by this factor */
 {
-    char propertyname[128], propertyvalue[128], *storedvalue;
+    char propertyname[128], propertyvalue[2048], *storedvalue;
     int ntok;
+    unsigned int noeditflag;
+
+    /* Save CDNOEDIT flag if set, and clear it */
+    noeditflag = cellDef->cd_flags & CDNOEDIT;
+    cellDef->cd_flags &= ~CDNOEDIT;
 
     /* Get first element line */
     if (dbFgets(line, len, f) == NULL) return (FALSE);
@@ -1408,7 +1413,10 @@ dbReadProperties(cellDef, line, len, f, scalen, scaled)
 	/* Skip blank lines */
 	while (line[0] == '\0')
 	    if (dbFgets(line, len, f) == NULL)
+	    {
+		cellDef->cd_flags |= noeditflag;
 		return (TRUE);
+	    }
 
 	/* Stop when at end of properties section (currently, only "string"
 	 * is defined)
@@ -1421,7 +1429,7 @@ dbReadProperties(cellDef, line, len, f, scalen, scaled)
 	 */
 	if (line[0] == 's')
 	{
-	    if ((ntok = sscanf(line, "string %127s %127[^\n]",
+	    if ((ntok = sscanf(line, "string %127s %2047[^\n]",
 		    propertyname, propertyvalue)) != 2)
 	    {
 		TxError("Skipping bad property line: %s", line);
@@ -1480,6 +1488,7 @@ nextproperty:
 	    break;
     }
 
+    cellDef->cd_flags |= noeditflag;
     return (TRUE);
 }
 
