@@ -24,7 +24,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWtools.c,v 1.3 2001/04/13 20:02:58 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/dbwind/DBWtools.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -56,6 +56,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWtools.c,v 1.3 20
 
 static CellDef *boxRootDef = NULL;	/* CellDef for the box */
 static Rect boxRootArea;		/* Root def coords */
+static Point crosshairPos;		/* Crosshair position */
 
 /*
  * If the following is DBW_SNAP_USER, the box gets snapped to the user's
@@ -67,7 +68,6 @@ int DBWSnapToGrid = DBW_SNAP_LAMBDA;
 /* Forward reference: */
 
 extern int DBWToolDraw();
-extern void toolSnapToGrid();
 
 
 /*
@@ -115,7 +115,7 @@ toolFindPoint(p, rootPoint, rootArea)
 
     WindPointToSurface(WindCurrentWindow, p, rootPoint, rootArea);
     if (DBWSnapToGrid != DBW_SNAP_INTERNAL)
-	toolSnapToGrid(WindCurrentWindow, rootPoint, rootArea);
+	ToolSnapToGrid(WindCurrentWindow, rootPoint, rootArea);
     return WindCurrentWindow;
     
 }
@@ -357,7 +357,160 @@ ToolGetCorner(screenPoint)
 	else return TOOL_TR;
     }
 }
-
+
+
+/*
+ * ----------------------------------------------------------------------------
+ * dbwCrosshairInit --
+ *
+ *	Set the initial crosshair position to MINFINITY, where it will
+ *	not display until explicitly set by a command.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Initializes static memory.
+ *	
+ * ----------------------------------------------------------------------------
+ */
+
+void
+dbwCrosshairInit()
+{
+    crosshairPos.p_x = MINFINITY;
+    crosshairPos.p_y = MINFINITY;
+    DBWHLAddClient(DBWDrawCrosshair);
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ * dbwRecordCrosshair[X,Y]Pos --
+ *
+ * 	This procedure tells the highlight manager that the crosshair's
+ *	current position needs to be erased or redisplayed.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Highlight redisplay information is logged.
+ * ----------------------------------------------------------------------------
+ */
+
+void
+dbwRecordCrosshairYPos(window, erase)
+    MagWindow *window;
+    bool erase;			/* TRUE means crossair is being erased from its
+				 * current position.  FALSE means the crosshair
+				 * is being added at a new position.
+				 */
+{
+    Rect xwire;
+
+    xwire.r_xbot = MINFINITY;
+    xwire.r_xtop = INFINITY;
+    xwire.r_ybot = xwire.r_ytop = crosshairPos.p_y;
+    DBWHLRedraw(WINDOW_DEF(window), &xwire, erase);
+}
+
+void
+dbwRecordCrosshairXPos(window, erase)
+    MagWindow *window;
+    bool erase;			/* TRUE means crossair is being erased from its
+				 * current position.  FALSE means the crosshair
+				 * is being added at a new position.
+				 */
+{
+    Rect xwire;
+
+    xwire.r_ybot = MINFINITY;
+    xwire.r_ytop = INFINITY;
+    xwire.r_xbot = xwire.r_xtop = crosshairPos.p_x;
+    DBWHLRedraw(WINDOW_DEF(window), &xwire, erase);
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBWDrawCrosshair --
+ *
+ * 	This procedure will redraw the crosshair in a given window, if
+ *	the crosshair is to appear in that window.  It is called only by
+ *	the highlight code.  The caller must lock the window.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	The crosshair is redrawn, unless it isn't supposed to appear.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+DBWDrawCrosshair(window, plane)
+    MagWindow *window;		/* Window in which to redraw box. */
+    Plane *plane;		/* Non-space tiles on this plane indicate
+				 * which highlight areas must be redrawn.
+				 */
+{
+    Point p;
+
+    WindPointToScreen(window, &crosshairPos, &p);
+
+    GrSetStuff(STYLE_YELLOW1);
+    if (p.p_x > window->w_screenArea.r_xbot &&
+		p.p_x < window->w_screenArea.r_xtop)
+	GrClipLine(p.p_x, window->w_screenArea.r_ybot,
+		   p.p_x, window->w_screenArea.r_ytop);
+
+    if (p.p_y > window->w_screenArea.r_ybot &&
+		p.p_y < window->w_screenArea.r_ytop)
+	GrClipLine(window->w_screenArea.r_xbot, p.p_y,
+		   window->w_screenArea.r_xtop, p.p_y);
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *	DBWSetCrosshair --
+ *
+ * 	Change the location of the crosshair.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Information is recorded so that the crosshair will be redrawn.
+ * ----------------------------------------------------------------------------
+ */
+
+void
+DBWSetCrosshair(window, pos)
+    MagWindow *window;
+    Point *pos;			/* New crosshair location in coords of rootDef. */
+{
+    if (crosshairPos.p_x != pos->p_x)
+    {
+	/* Record the old and area of the vertical line for redisplay. */
+	dbwRecordCrosshairXPos(window, TRUE);
+
+	/* Update the crosshair location. */
+	crosshairPos.p_x = pos->p_x;
+
+	/* Record the new area for redisplay. */
+	dbwRecordCrosshairXPos(window, FALSE);
+    }
+
+    /* Do the same thing for the horizontal crosshair line */
+    if (crosshairPos.p_y != pos->p_y)
+    {
+	dbwRecordCrosshairYPos(window, TRUE);
+	crosshairPos.p_y = pos->p_y;
+	dbwRecordCrosshairYPos(window, FALSE);
+    }
+}
+
 /*
  * ----------------------------------------------------------------------------
  * dbwRecordBoxArea --
@@ -466,10 +619,11 @@ DBWDrawBox(window, plane)
      */
 
     WindSurfaceToScreen(window, &boxRootArea, &screenArea);
+
     if ((screenArea.r_xbot == screenArea.r_xtop) &&
 	    (screenArea.r_ybot == screenArea.r_ytop))
     {
-	GrSetStuff(STYLE_DRAWBOX);
+	GrSetStuff(STYLE_OUTLINEHIGHLIGHTS);
 	GrFastBox(&screenArea);
 	GEO_EXPAND(&screenArea, 1, &screenArea);
 	GrFastBox(&screenArea);
@@ -487,7 +641,7 @@ DBWDrawBox(window, plane)
 	    || ((screenArea.r_ytop != screenArea.r_ybot) &&
 	    (screenArea.r_ytop < screenArea.r_ybot + 4)))
     {
-	GrClipBox(&screenArea, STYLE_DRAWBOX);
+	GrClipBox(&screenArea, STYLE_OUTLINEHIGHLIGHTS);
 	return;
     }
 
@@ -497,8 +651,9 @@ DBWDrawBox(window, plane)
     {
 	side = screenArea;
 	side.r_xtop = side.r_xbot + 2 - GrPixelCorrect;
-	if (side.r_ytop != side.r_ybot)
+	if (side.r_ytop != side.r_ybot) {
 	    GrFastBox(&side);
+	}
     }
     if ((screenArea.r_ybot >= window->w_screenArea.r_ybot) &&
 	(screenArea.r_ybot <= window->w_screenArea.r_ytop))
@@ -506,8 +661,9 @@ DBWDrawBox(window, plane)
 	side = screenArea;
 	side.r_ytop = side.r_ybot + 1;
 	if (!GrPixelCorrect) side.r_ybot--;
-	if (side.r_xtop != side.r_xbot)
+	if (side.r_xtop != side.r_xbot) {
 	    GrFastBox(&side);
+	}
     }
     if ((screenArea.r_xtop >= window->w_screenArea.r_xbot) &&
 	(screenArea.r_xtop <= window->w_screenArea.r_xtop))
@@ -515,16 +671,18 @@ DBWDrawBox(window, plane)
 	side = screenArea;
 	side.r_xbot = side.r_xtop - 1;
 	if (!GrPixelCorrect) side.r_xtop++;
-	if (side.r_ytop != side.r_ybot)
+	if (side.r_ytop != side.r_ybot) {
 	    GrFastBox(&side);
+	}
     }
     if ((screenArea.r_ytop >= window->w_screenArea.r_ybot) &&
 	(screenArea.r_ytop <= window->w_screenArea.r_ytop))
     {
 	side = screenArea;
 	side.r_ybot = side.r_ytop - 2 + GrPixelCorrect;
-	if (side.r_xtop != side.r_xbot)
+	if (side.r_xtop != side.r_xbot) {
 	    GrFastBox(&side);
+	}
     }
 }
 
@@ -800,7 +958,7 @@ ToolMoveCorner(corner, point, screenCoords, rootDef)
 /*
  * ----------------------------------------------------------------------------
  *
- * toolSnapToGrid --
+ * ToolSnapToGrid --
  *
  * Snap the point *p (in root cell coordinates) to the nearest
  * point in the user-defined grid or the nearest integer lambda value,
@@ -816,7 +974,7 @@ ToolMoveCorner(corner, point, screenCoords, rootDef)
  */
 
 void
-toolSnapToGrid(w, p, rEnclose)
+ToolSnapToGrid(w, p, rEnclose)
     MagWindow *w;
     Point *p;
     Rect *rEnclose;
