@@ -6,14 +6,12 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/lef/lefCmd.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/lef/lefCmd.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -123,20 +121,22 @@ CmdLef(w, cmd)
 
     if (option != LEF_HELP)
     {
-        windCheckOnlyWindow(&w, DBWclientID);
-        if (w == (MagWindow *) NULL)
-        {
-            if (ToolGetBox(&selectedDef,NULL) == FALSE)
-            {
-                TxError("Point to a window first\n");
-                return;
-            }
-            selectedUse = selectedDef->cd_parents;
-        }
-        else
-        {
-            selectedUse = (CellUse *)w->w_surfaceID;
-        }
+        selectedUse = CmdGetSelectedCell((Transform *)NULL);
+	if (selectedUse == NULL)
+	{
+	    windCheckOnlyWindow(&w, DBWclientID);
+	    if (w == (MagWindow *) NULL)
+	    {
+		if (ToolGetBox(&selectedDef,NULL) == FALSE)
+		{
+		    TxError("Point to a window first\n");
+		    return;
+		}
+		selectedUse = selectedDef->cd_parents;
+	    }
+	    else
+		selectedUse = (CellUse *)w->w_surfaceID;
+	}
     }
 
     switch (option)
@@ -191,14 +191,16 @@ CmdLef(w, cmd)
 		}
 		else if (cmd->tx_argc != 3) goto wrongNumArgs;
 	    }
-            else if (cmd->tx_argc != 3) goto wrongNumArgs;
-            namep = cmd->tx_argv[2];
-            selectedUse = CmdGetSelectedCell((Transform *) NULL);
+            else if (cmd->tx_argc != 2) goto wrongNumArgs;
             if (selectedUse == NULL)
             {
                 TxError("No cell selected\n");
                 return;
             }
+            if (cmd->tx_argc == 2)
+		namep = selectedUse->cu_def->cd_name;
+	    else
+		namep = cmd->tx_argv[2];
 	    if (!is_lef)
 		DefWriteCell(selectedUse->cu_def, namep, allSpecial);
 	    else
