@@ -693,13 +693,17 @@ proc magic::toolupdate {win {yesno "yes"} {layerlist "none"}} {
 	 labels {set canon $layer}
 	 default {set canon [magic::tech layer $layer]}
       }
+
+      # Layers may not be in the toolbar if "hidelocked" or
+      # "hidespecial" is used, so catch each configure command.
+
       if {$canon != ""} {
          if {$yesno == "yes"} {
-	    ${framename}.toolbar.b$canon configure -image img_$canon 
-	    ${framename}.toolbar.p$canon configure -image pale_$canon 
+	    catch {${framename}.toolbar.b$canon configure -image img_$canon}
+	    catch {${framename}.toolbar.p$canon configure -image pale_$canon}
          } else {
-	    ${framename}.toolbar.b$canon configure -image img_space
-	    ${framename}.toolbar.p$canon configure -image img_space
+	    catch {${framename}.toolbar.b$canon configure -image img_space}
+	    catch {${framename}.toolbar.p$canon configure -image img_space}
 	 }
       }
    }
@@ -1310,7 +1314,7 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
    $m add command -label "New" -command "magic::openwrapper"
    $m add command -label "Set Editable" -command \
 		"pushbox ; select top cell ; edit ; popbox"
-   $m add command -label "Close" -command "magic::closewrapper ${framename}"
+   $m add command -label "Close" -command "closewrapper ${framename}"
    $m add separator
    $m add command -label "Full View" -command {magic::view}
    $m add command -label "Redraw" -command {magic::redraw}
@@ -1515,8 +1519,9 @@ proc magic::addcommandentry { framename } {
       ${framename}.pane paneconfigure ${framename}.pane.bot -minsize 50
    }
    set entercmd [bind ${framename}.pane.top.magic <Enter>]
-   set bindstr "$entercmd ; macro XK_colon \"focus ${commandframe}.eval.text\" ;\
-		alias puts tkshell::PutsTkShell ; set Opts(redirect) 1"
+   set bindstr "$entercmd ; macro XK_colon \"set Opts(redirect) 1;\
+		focus ${commandframe}.eval.text\";\
+		alias puts tkshell::PutsTkShell"
    bind ${commandframe}.eval <Enter> \
 	"focus ${commandframe}.eval.text ; set Opts(focus) $framename ;\
 	catch {unset Opts(redirect)}"
